@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisHapusBuku:
-    id_hapus_buku: str
+    id_hapus_buku: int
     ket_hapus_buku: str
     u_prasarana: str
     u_sarana: str
@@ -14,3 +13,6 @@ class JenisHapusBuku:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.ket_hapus_buku
